@@ -487,7 +487,19 @@ $(function() {
 			}
 		});
 	});
-	
+
+	// Handle the dump ppi tree action
+	$(document).on('action-dump-ppi-tree', function() {
+		var editor = GetCurrentEditor();
+		$.post('/dump-ppi-tree', {"source": editor.getValue()}, function(data) {
+			if(data.error == '') {
+				$("#output").val(data.output);
+			} else {
+				$("#output").val(data.error);
+			}
+		});
+	});
+
 	// Add an empty one editor tab on startup
 	AddEditorTab();
 
